import SimpleOpenNI.*;
import java.awt.Color;
import java.util.Iterator;

SingleUserKinect kinect;

PVector userPosRealWorld = new PVector(); // 3d user position
float comX; // Center of Mass X
float maxX =  500; // 1/2 meter  (0 is in the middle)
float minX =  -500; // -1/2 meter (0 is in the middle)

/* STUDENT: Adjust this value to the right number of images you have */
int numImages = 115; // total number of images
int startNumImage = 1; // first number in sequence

PImage[] images = new PImage[numImages]; // the images will be stored in this list

boolean USE_KINECT = true;

// setup is executed once, when the program started
void setup() {

  // size of the window
  //size(400,400);// use size "(displayWidth, displayHeight)" for fullscreen  
  size(displayWidth, displayHeight);

  // set frame background to black (this is the background you'll see in Present Mode)
  ((javax.swing.JFrame)frame).getContentPane().setBackground(java.awt.Color.black);
  // load the image sequence
  loadImageSequence();

  // user SingleUserKinect for tracking.
  if (USE_KINECT) {
    kinect = new SingleUserKinect(this);
  }
}

// draw is repeatedly executed, as fast as possible, or according to frameRate setting
void draw() {
  background(0); // draw a black background
  
  // update user position
  if (USE_KINECT) {
    kinect.update();
  }

  // set center of mass to the maximum value
  float comX = maxX;

  // if we are tracking a user, get the position of his Center of Mass
  if (USE_KINECT) {  
    if (kinect.trackedUserId != 0) { 
      kinect.getCoM(userPosRealWorld);    
      comX = userPosRealWorld.x;
      if (comX > maxX) {
        comX = maxX;
      } else if (comX < minX) {
        comX = minX;
      }
    }
  }
  // if we're not using a kinect, use mouseX position
  else {
    comX = mouseX;
    minX = 0;
    maxX = width;
  }


  // map x position to an image in the sequence
  int imgInSeq = (int)map(comX, minX, maxX, 0, numImages - 1); // map center of mass to image in sequence

  // draw the image scaled and stretched to the window size
  image(images[imgInSeq], 0, 0, width, height);
}

// load the image sequence
void loadImageSequence() {
  String filename = "";

  for (int i = 0; i < numImages; i++) {
    // STUDENT: adjust how the filename is being generated to fit the naming of your files
    filename = "headtrack/img__" +nf(startNumImage + i, 3) + ".jpg";   
    images[i] = loadImage(filename);
  }
}


// -----------------------------------------------------------------
// SimpleOpenNI user events
// -----------------------------------------------------------------
// onNewUser is triggered when the kinect registers a new user
void onNewUser(SimpleOpenNI curContext, int userId)
{
  // let our SingleUserKinect Class take care of this
  kinect.registerNewUser(curContext, userId);
}

// onLostUser is triggered when the kinect deregisters a user
void onLostUser(SimpleOpenNI curContext, int userId)
{
  // let our SingleUserKinect Class take care of this
  kinect.deRegisterUser(curContext, userId);
}

